pub fn extract_page_chunks(
doc: &Document,
page_number: u32,
page_id: ObjectId,
) -> Result<PageChunks, EdgePdfError>Expand description
Extract all chunks from a single page in one content stream pass.
pub fn extract_page_chunks(
doc: &Document,
page_number: u32,
page_id: ObjectId,
) -> Result<PageChunks, EdgePdfError>Extract all chunks from a single page in one content stream pass.