Module raster_table_ocr

Module raster_table_ocr 

Recover text signal from raster table images using local OCR.

Functions

recover_dominant_image_text_chunks
Recover OCR text lines from dominant non-table page images.
recover_page_raster_table_cell_text
Recover OCR text into empty bordered tables by rasterizing the full page.
recover_raster_table_borders
Recover synthetic table borders for strongly numeric raster tables.
recover_raster_table_text_chunks
Recover OCR text chunks for image-backed table regions on a single page.