pub fn configure_thread_pool(
num_threads: usize,
) -> Result<(), ThreadPoolBuildError>Expand description
Configure the global rayon thread pool with the given number of threads.
On WASM, this is a no-op.
pub fn configure_thread_pool(
num_threads: usize,
) -> Result<(), ThreadPoolBuildError>Configure the global rayon thread pool with the given number of threads.
On WASM, this is a no-op.