Module language_detector

Module language_detector 

Simple trigram-based language detection.

Uses character trigram frequency profiles for the most common languages. No external dependencies — profiles are embedded as static data.

Structs

LangDetection
Detected language result.

Functions

detect_language
Detect the most likely language of the given text.