pub fn detect_language(text: &str) -> Option<LangDetection>Expand description
Detect the most likely language of the given text.
Returns None if the text is too short (< 20 characters after cleanup).
pub fn detect_language(text: &str) -> Option<LangDetection>Detect the most likely language of the given text.
Returns None if the text is too short (< 20 characters after cleanup).