pub fn classify_layout(
elements: &[ContentElement],
page_width: f64,
) -> LayoutTypeExpand description
Classify the layout type of a page based on its content elements.
pub fn classify_layout(
elements: &[ContentElement],
page_width: f64,
) -> LayoutTypeClassify the layout type of a page based on its content elements.