pub struct ModeWeightStatistics { /* private fields */ }Expand description
Mode-weighted font statistics for heading/paragraph classification.
Implementations
Sourceimpl ModeWeightStatistics
impl ModeWeightStatistics
Sourcepub fn add(&mut self, font_size: f64, char_count: usize)
pub fn add(&mut self, font_size: f64, char_count: usize)
Add a font size observation with the given character count.
Sourcepub fn mode_font_size(&self) -> Option<f64>
pub fn mode_font_size(&self) -> Option<f64>
Get the mode (most frequent) font size.
Sourcepub fn total_count(&self) -> usize
pub fn total_count(&self) -> usize
Total character count.
Sourcepub fn is_larger_than_mode(&self, font_size: f64) -> bool
pub fn is_larger_than_mode(&self, font_size: f64) -> bool
Whether a font size is larger than the mode (potential heading).
Sourcepub fn is_mode_size(&self, font_size: f64) -> bool
pub fn is_mode_size(&self, font_size: f64) -> bool
Whether a font size matches the mode (body text).