pub fn load_with_password(
data: &[u8],
password: Option<&str>,
) -> Result<Document, EdgePdfError>Expand description
Try to load a PDF with an optional password.
Returns the loaded document or an error if the password is wrong or the file is otherwise unreadable.