Module raster_table_ocr

Module raster_table_ocr 

Recover text signal from raster table images using local OCR.

Functions

recover_raster_table_borders
Recover synthetic table borders for strongly numeric raster tables.
recover_raster_table_text_chunks
Recover OCR text chunks for image-backed table regions on a single page.